<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:nk="http://netkernel.org" xmlns:xrl="http://netkernel.org/xrl">
	<xsl:output method="xml" />

	<xsl:param name="search" nk:class="java.lang.String" />

	<xsl:template match="/hits">
		<div>

			<xrl:include>
			 <xrl:identifier>active:controlPanelInfoBox</xrl:identifier>
			 <xrl:argument name="content">
			   <div>
			   	<p>
             The NetKernel search system is based on the Lucene search engine and uses the
             <a href="http://lucene.apache.org/java/2_3_2/queryparsersyntax.html">Lucene search syntax</a>
             for search queries.
           </p>
           <p>
             Entering a simple search is easy - simply enter a search term in the search box
             and click the button labeled "search".
           </p>
           <p>
             A search phrase consisting of multiple words is contained within quotation marks,
             such as <i>&quot;java accessor&quot;</i>.
             Logical operators (AND, OR, NOT) can be used with search terms and search phrases,
             such as <i>java AND endpoint AND transient</i>.
             Plus ("+") and minus ("-") sign can also be used such as <i>+&quot;java accessor&quot; +endpoint -script</i>.
           </p>
           <p>
             Terms may be grouped with parenthesis, for example the query
             <i>(groovy OR ruby) AND accessor</i> will search for documents with
             accessor and either groovy or ruby.
           </p>
           <p>
             Wildcard searches use the question mark ("?") and asterisk
             ("*") characters. The question mark will substitute
             any single character, such as te?t will match text and test.
             The asterisk character will substitute zero or more characters.
           </p>
           <p>
             The tilde ("~") indicates a fuzzy search.
             For example roam~ will match foam and roam.
           </p>
           <p>
             The search system also supports the specification of
             fields.
             These are designated as prefix.
             For example, to search for all entries
             in the category "apposite", enter the search
             query category:apposite +http, which will
             search for apposite package descriptions
             which include the term "http".
             The fields used by NetKernel include:
             <ul>
               <li>title</li>
               <li>category</li>
               <li>desc</li>
               <li>keyword</li>
             </ul>
           </p>
           <p>
             If no colon (":") characters are included in the search NetKernel uses the following
             Lucene search structure as the default:
             <br/><br/>
             search="default:("+search+")  title:("+search+"^2)  desc:("+search+") keywords:("+search+")";
             <br/><br/>
           </p>
			   </div>
			 </xrl:argument>
			</xrl:include> 

			<form action="" method="get">
				<table>
					<tr>
						<td>
							<input type="text" name="search">
								<xsl:attribute name="value"><xsl:value-of select="$search" /></xsl:attribute>
							</input>
						</td>
						<td>
							<input type="submit" value="search"  class="btn"/>
						</td>
					</tr>
				</table>
			</form>
			<p>
				Found
				<xsl:value-of select="total" />
				hits in
				<xsl:value-of select="time" />
				seconds.
			</p>
			<xsl:if test="hit">
			<table cellspacing="0" cellpadding="1" width="600" class="data-table">
				<xsl:apply-templates />
			</table>
			</xsl:if>
		</div>
	</xsl:template>

	<xsl:template match="hit">
		<tr>
			<td>
				<a href="/tools/search/resolver?resolverID={field[name='resolverID']/value}&amp;documentID={field[name='documentID']/value}" class="template-lb">
					<div>
						<xsl:variable name="score">
							<xsl:choose>
								<xsl:when test="score &gt; 1.0">1.0</xsl:when>
								<xsl:otherwise><xsl:value-of select="score"/></xsl:otherwise>
							</xsl:choose>
						</xsl:variable>
						<div style="margin-top: 5px; margin-right: 5px; float: right; ">
							<span title="{format-number($score, '#0%')}" >
								<span style="background: #219b3f;"><img src="/nkse/style/img/blank.png" width="{$score*50}" height="16"/></span>
								<span style="background: white;" ><img src="/nkse/style/img/blank.png" width="{(1-$score)*50}" height="16"/></span>
							</span>
						</div>
						<div class="template-icon-title">
							<xsl:choose>
								<xsl:when test="field[name='dtitle']">
									<xsl:value-of select="field[name='dtitle']/value" /><xsl:text> </xsl:text>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="field[name='title']/value" /><xsl:text> </xsl:text>
								</xsl:otherwise>
							</xsl:choose>
						</div>
						<div class="template-icon-subtitle">
							<xsl:value-of select="field[name='desc']/value" /><xsl:text> </xsl:text>
						</div>
					</div>
				</a>
			</td>
		</tr>

	</xsl:template>

	<xsl:template match="text()" />

</xsl:stylesheet>
