package org.netkernel.nkse.search.endpoint;

import org.netkernel.layer0.nkf.INKFRequest;
import org.netkernel.layer0.nkf.INKFRequestContext;
import org.netkernel.layer0.nkf.NKFException;
import org.netkernel.layer0.representation.IHDSInversion;
import org.netkernel.layer0.representation.IHDSNode;
import org.netkernel.layer0.representation.IHDSNodeList;
import org.netkernel.module.standard.endpoint.StandardAccessorImpl;

public class SearchResolverAccessor extends StandardAccessorImpl
{
	public SearchResolverAccessor()
	{	this.declareThreadSafe();
	}

	@Override
	public void onSource(INKFRequestContext context) throws Exception
	{	
		String resolverID=context.source("arg:resolverID",String.class);
		String documentID=context.source("arg:documentID",String.class);
		String mode=context.getThisRequest().getArgumentValue("mode");
		
		INKFRequest req=context.createRequest("active:spaceAggregateHDS");
		req.addArgument("uri", "res:/etc/system/SearchIndexEngine.xml");
		req.setRepresentationClass(IHDSInversion.class);
		IHDSInversion i=(IHDSInversion)context.issueRequest(req);
		
		IHDSNodeList nl=i.getNodes(resolverID);
		IHDSNode n=nl.get(0);
		String resolver=(String)n.getParent().getValue();
		n=n.getParent().getParent().getParent();
		String space=(String)n.getFirstValue("id");
		String version=(String)n.getFirstValue("version");
		req=context.createRequest("active:wormhole");
		req.addArgument("space", space);
		req.addArgument("version", version);
		req.addArgument("uri", resolver+"+documentID@"+documentID);
		req.setRepresentationClass(String.class);
		String redirect=(String)context.issueRequest(req);
		
		if (mode.equals("redirect"))
		{	context.sink("httpResponse:/redirect", redirect);
		}
		else if (mode.equals("identifier"))
		{	context.createResponseFrom(redirect);
		}
		else
		{	throw new NKFException("unsupported mode");
		}
	}

}
